.. |icon| image:: docs/source/resource/icon/icon_pixel.png

.. figure:: docs/source/resource/image/splash.png

|icon| Welcome to the Platform!
###############################

`[Demo Video] <https://youtu.be/d1mj8yzjr-w>`_ | `[Discord] <https://discord.gg/BkMmFUC>`_ | `[Twitter] <https://twitter.com/jsuarez5341>`_

Neural MMO is a massively multiagent environment for artificial intelligence research inspired by Massively Multiplayer Online (MMO) role-playing games. The project is under active development with major updates every 3-6 months. This README is a stub -- all of our `[Documentation] <https://jsuarez5341.github.io>`_ is hosted by github.io.
